/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2009-2015.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#ifndef __NAMESPACE_HPP__
#define __NAMESPACE_HPP__

/**
 * @brief       The namespace fwZip provides IO for compress/uncompress .zip files using zlib .
 * @namespace   fwZip
 *
 * @date        2009-2010.
 *
 */
namespace fwZip
{
}
#endif /* __NAMESPACE_HPP__ */
